"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseUsingCache = void 0;
const lru_cache_1 = __importDefault(require("lru-cache"));
const parse_1 = require("./parse");
let cache;
/**
 * Returns Elm's string representation as a JS value.
 *
 * Unlike parse(), the function uses LRU cache
 * before attempting to parse value.
 *
 * Examples:
 * * '' -> null
 * * '42' -> 42
 * * '"42"' -> "42" (string)
 * * '{a = 1, b = 2}' -> {a: 1, b: 2} (json)
 * * '{0 = "a", 1 = 42}' -> ["a", 42] (array)
 */
const parseUsingCache = (text) => {
    if (!cache) {
        cache = new lru_cache_1.default(100);
    }
    let valueInCache = cache.get(text);
    if (typeof valueInCache === "undefined") {
        try {
            valueInCache = (0, parse_1.parse)(text);
        }
        catch (e) {
            valueInCache = e;
        }
        cache.set(text, valueInCache);
    }
    if (valueInCache instanceof Error) {
        throw valueInCache;
    }
    return valueInCache;
};
exports.parseUsingCache = parseUsingCache;
//# sourceMappingURL=parseUsingCache.js.map